@@ -5,7 +5,7 @@ import os
 import stat
 import tarfile
 import time
-
+import uuid
 from distutils.version import LooseVersion
 from pathlib import Path
 from typing import IO, TYPE_CHECKING, Iterator, Optional
@@ -15,9 +15,8 @@ import requests
 
 from ensureconda.resolve import is_windows, platform_subdir, site_path
 
-
 if TYPE_CHECKING:
-    from _typeshed import AnyPath
+    from _typeshed import StrPath
 
 
 def request_url_with_retry(url: str) -> requests.Response:
@@ -105,9 +104,16 @@ def exe_suffix() -> str:
 
 
 @contextlib.contextmanager
-def new_executable(target_filename: "AnyPath") -> Iterator[IO[bytes]]:
+def new_executable(target_filename: "Path") -> Iterator[IO[bytes]]:
+    """Create a new executabler that can be written to.
+
+    Care is take to both prevent concurrent writes as well as guarding against
+    early reads.
+    """
     with filelock.FileLock(f"{str(target_filename)}.lock"):
-        with open(target_filename, "wb") as fo:
+        temp_filename = target_filename.with_name(uuid.uuid4().hex)
+        with open(temp_filename, "wb") as fo:
             yield fo
-        st = os.stat(target_filename)
-        os.chmod(target_filename, st.st_mode | stat.S_IXUSR)
+        st = os.stat(temp_filename)
+        os.chmod(temp_filename, st.st_mode | stat.S_IXUSR)
+        os.rename(temp_filename, target_filename)
